<?php

namespace App\Http\Controllers\admin;

use App\Http\Controllers\Controller;
use App\Mail\PacienteAgendaDoctor;
use App\Models\Agenda;
use App\Models\Doctor;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Mail;

class AgendaController extends Controller
{

    public function index(Request $request)
    {
        $agendas = DB::table('agendas as ag')
            ->join('doctores as doc', 'ag.doctor_id', '=', 'doc.id')
            ->select('doc.nombre', 'ag.paciente', 'ag.fecha', 'ag.hora', 'ag.tratamiento')
            ->whereDate('fecha', date('Y-m-d', strtotime('+ 2 days')))
            ->orWhereDate('fecha', date('Y-m-d', strtotime('+ 1 days')))
            ->orderBy('fecha', 'asc')
            ->orderBy('hora', 'asc')
            ->get();
        $pacientes = $this->showAgendaDoctor($request);
        $doctore = Doctor::all();
        return view('admin.agenda.index', ['agendas' => $agendas, 'doctores' => $doctore, 'pacientes' => $pacientes]);
    }

    public function store(Request $request)
    {
       $agenda = Agenda::create($request->all());

        $email = Doctor::findOrFail($request->doctor_id)->email;

        // Mail::to($email)->send(new PacienteAgendaDoctor($agenda->id)); 

        return back()->with(['info' => 'Paciente Agendado Con Exito', 'color' => 'success']);
    }

    public function delete($id)
    {
        // dd($id);
        Agenda::find($id)->delete();
        return back()->with(['info' => 'Paciente Agendado Eliminado Con Exito', 'color' => 'danger']);
    }

    public function showAgendaDoctor(Request $request)
    {
        $agenda = Agenda::whereBetween('fecha', [$request->f_inicio, $request->f_final])
            ->where('doctor_id', $request->doctor)
            ->orderBy('fecha', 'asc')
            ->orderBy('hora', 'asc')
            ->get();
        return $agenda;
    }

    public function edit($id)
    {
        $data = Agenda::find($id);

        $doctores = Doctor::all();
        return view('admin.agenda.edit', ['data' => $data, 'doctores' => $doctores, 'id' => $id]);
    }

    public function update(Request $request)
    {
        Agenda::findOrFail($request->id)->update($request->all());

        return back()->with(['info' => 'actualizado con exito', 'color' => 'success']);
    }
}
