<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Insumo;
use App\Models\SalidaInsumo;
use Illuminate\Http\Request;
use Illuminate\Http\Response;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Gate;

class InsumoController extends Controller
{

    public function index()
    {
        abort_if(Gate::denies('insumo_list'), Response::HTTP_FORBIDDEN, 'Forbidden');

        return view('admin.insumos.index', ['insumos' => Insumo::all()]);
    }

    public function create()
    {
        abort_if(Gate::denies('insumo_store'), Response::HTTP_FORBIDDEN, 'Forbidden');

        return view('admin.insumos.create');
    }

    public function show($id)
    {
        abort_if(Gate::denies('insumo_update'), Response::HTTP_FORBIDDEN, 'Forbidden');
        return view('admin.insumos.show', ['insumo' => Insumo::find($id)]);
    }

    public function store(Request $request)
    {
        abort_if(Gate::denies('insumo_store'), Response::HTTP_FORBIDDEN, 'Forbidden');

        Insumo::create($request->all());
        storeControl('registro un nuevo insumo');

        return back()->with(['info' => 'insumo registrado con exito', 'color' => 'success']);
    }

    public function update(Request $request, Insumo $insumo)
    {
        abort_if(Gate::denies('insumo_update'), Response::HTTP_FORBIDDEN, 'Forbidden');
        Insumo::find($request->id)->update($request->all());
        return back()->with(['info' => 'insumo actualizado con exito', 'color' => 'warning']);
    }

    public function destroy(Insumo $insumo)
    {
        abort_if(Gate::denies('insumo_delte'), Response::HTTP_FORBIDDEN, 'Forbidden');
        $insumo->delete();
        storeControl('elimino un insumo');

        return back()->with(['info' => 'insumo eliminado con exito', 'color' => 'danger']);
    }

    public function reportPrint()
    {
        return view('reports.insumos.all', ['insumos' => Insumo::all()]);
    }


    // retona la vista para visulizar y seleccionar reportes
    public function reportPrints()
    {
        return view('admin.insumos.reporte');
    }


    // ------- salida de insumos

    // retorna la vista de salidas de Insumos
    public function salidas()
    {

        $salidas = DB::table('salida_insumos as si')
            ->join('insumos as in', 'si.insumo_id', '=', 'in.id')
            ->join('users as us', 'si.user_id', '=', 'us.id')
            ->select(
                'si.cantidad',
                'si.clinica',
                'si.created_at',
                'si.id',
                'in.nombre as insumo',
                'in.id as insumo_id',
                'us.name'
            )
            ->orderBy('si.id', 'desc')
            ->paginate(30);
        return view('admin.insumos.salidas.index', ['salidas' => $salidas, 'insumos' => Insumo::all()]);
    }

    // guarda la salida de un insumo
    public function salidaStore(Request $request)
    {
        $insumo = Insumo::find($request->insumo_id);

        if($request->cantidad > $insumo->cantidad) {
            return back()->with(['info' => 'la cantidad supera el stock', 'color' => 'warning']);

        }
        SalidaInsumo::create($request->all());
        $insumo->cantidad -= $request->cantidad;
        $insumo->save();
        storeControl('registro una salida de insumos');

        return back()->with(['info' => 'salida de insumo registrado con exito', 'color' => 'success']);
    }


    // elimina un salida
    public function deleteSalida(Request $request)
    {
        SalidaInsumo::find($request->id)->delete();
        $insumo = Insumo::find($request->insumo_id);
        $insumo->cantidad += $request->cantidad;
        $insumo->save();
        storeControl('elimino un registro de insumo');

        return back()->with(['info' => 'salida de insumo eliminada con exito', 'color' => 'danger']);
    }

    // genera el reporte de salida de Insumos
    public function salidasReporteDate(Request $request)
    {
        $salidas = DB::table('salida_insumos as si')
            ->join('insumos as in', 'si.insumo_id', '=', 'in.id')
            ->join('users as us', 'si.user_id', '=', 'us.id')
            ->select(
                'si.cantidad',
                'si.clinica',
                'si.created_at',
                'si.id',
                'in.nombre as insumo',
                'in.id as insumo_id',
                'us.name'
            )
            ->orderBy('si.id', 'desc')
            ->whereBetween('si.created_at', [$request->desde, $request->hasta])
            ->get();
        return view('reports.insumos.salidas', ['salidas' => $salidas]);
    }
}
