<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\DeudaPaciente;
use App\Models\Procedimiento;
use App\Models\Tratamiento;
use Illuminate\Http\Request;
use Illuminate\Http\Response;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Gate;

class TratamientoController extends Controller
{

    public function index()
    {
        abort_if(Gate::denies('tratamiento_listado'), Response::HTTP_FORBIDDEN, 'Forbidden');
        $tratamientos  = Tratamiento::all();
        return view('admin.tratamiento.index', ['tratamientos' => $tratamientos]);
    }

    public function create()
    {
        abort_if(Gate::denies('tratamiento_store'), Response::HTTP_FORBIDDEN, 'Forbidden');
        return view('admin.tratamiento.create');
    }

    public function store(Request $request)
    {
        abort_if(Gate::denies('tratamiento_store'), Response::HTTP_FORBIDDEN, 'Forbidden');
        Tratamiento::create($request->all());
        return back()->with(['info' => 'Tratamiento Creado Con Exito', 'color' => 'success']);
    }

    public function show($id)
    {
        abort_if(Gate::denies('tratamiento_update'), Response::HTTP_FORBIDDEN, 'Forbidden');

        $trata = Tratamiento::find($id);
        return view('admin.tratamiento.show', ['tratamiento' => $trata]);
    }

    public function update(Request $request, Tratamiento $tratamiento)
    {
        abort_if(Gate::denies('tratamiento_update'), Response::HTTP_FORBIDDEN, 'Forbidden');

        $tratamiento->update($request->all());
        return back()->with(['info' => 'Tratamiento Actualizado con Exito', 'color' => 'warning']);
    }

    public function destroy($id)
    {
        abort_if(Gate::denies('tratamiento_update'), Response::HTTP_FORBIDDEN, 'Forbidden');
        Tratamiento::find($id)->delete();
        return back()->with(['info' => 'Tratamiento  Eliminado con Exito', 'color' => 'danger']);
    }

    public function reportes()
    {
        $tratamiento = Tratamiento::all();
        return view('admin.tratamiento.reportes', compact('tratamiento'));
    }

    public function printAll()
    {
        return view('reports.tratamientos.all', ['tratamientos' => Tratamiento::all()]);
    }

    // retorna los tratamientos de mas a menos
    function masToMinus(Request $request) {
        $data = DeudaPaciente::join('tratamientos as tr', 'deuda_pacientes.tratamiento_id', '=', 'tr.id')
        ->select(DB::raw('count(tratamiento_id) as trid'), 'tr.nombre', 'tr.descripcion', 'tr.tipo')
        ->groupby('deuda_pacientes.tratamiento_id')
        ->whereBetween('deuda_pacientes.created_at', [$request->inicio, $request->fin])
        ->orderBy('trid', 'desc')
        ->get();
        return view('reports.tratamientos.minusandmore', compact('data', 'request'));
    }

    function faltantesOperacion(Request $request) {

        $data = Procedimiento::where('estado_pago', '0')->where('tratamiento_id', $request->tratamiento_id)->whereBetween('created_at', [$request->inicio, $request->fin])->groupby('tratamiento_id')->get();
        return view('reports.tratamientos.faltantes', compact('data'));
    }

    function totalTratamiento(Request $request) {
        $data = DeudaPaciente::whereBetween('deuda_pacientes.created_at', [$request->inicio, $request->fin])->where('tratamiento_id', $request->tratamiento_id)->get();
        return view('reports.tratamientos.totaltesTratamiento', compact('data'));
    }
}
