<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Articulo;

use App\Models\Factura;
use App\Models\Paciente;
use App\Models\Venta;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

class VentasController extends Controller
{
    public function index()
    {
        $articulos = DB::table('articulos as art')
            ->join('categoria as cat', 'art.categoria_id', '=', 'cat.id')
            ->select('art.id', 'art.nombre', 'art.stock', 'art.p_venta', 'art.cod_barras as code', 'art.descripcion', 'cat.nombre as catNom', 'art.descripcion_interna', 'art.img')
            ->where('art.stock', '>', 0)
            ->where('art.deleted_at', null)
            ->get();
        $pacientes = Paciente::all();

        return view('admin.ventas.index', ['articulos' => $articulos, 'pacientes' => $pacientes]);
    }

    // crea una venta
    public function store(Request $data)
    {
        $vuelta =  count($data->idArticulos);
        $factura = new Factura();
        $mayorista = false;
        if ($data->mayorista_check) {
            $mayorista = true;
        }
        if ($data->mayorista_check == null) {
            $mayorista = false;
        }
        $newdescuento = 0;
        if ($data->descuento_mayo) {
            $factura->descuento = $data->descuento_mayo;
            $newdescuento =  $data->totalventa -  $data->descuento_mayo;
            $mayorista = true;
        }

        if ($data->descripcion) {
            $factura->descripcion =  $data->descripcion;
        }
        $factura->total = $data->totalventa;
        $factura->descripcion_min = $data->des_min;
        $factura->mayoristas = $mayorista;
        $factura->total_des = $newdescuento;
        $factura->save();
        $clientename = null;
        $cliente_id = 1;
        $credito = false;

        if ($data->cliente && ($data->paciente_id == null)) {
            $clientename = $data->cliente;
        }

        if ($data->paciente_id !== null) {
            $p = Paciente::find($data->paciente_id);
            $clientename = $p->nombre;
        }

        for ($i = 0; $i < $vuelta; $i++) {
            $venta = new Venta();
            $venta->articulo_id = $data->idArticulos[$i];
            $venta->paciente_id = $cliente_id;
            $venta->cliente = $clientename;
            $venta->factura_id = $factura->id;
            $venta->credito = $credito;
            $venta->cantidad = $data->cantidad[$i];
            $venta->descuento = $data->descuento[$i];
            $venta->mayorista = $mayorista;
            $venta->total = $data->subtotal[$i];

            $articulo = Articulo::find($data->idArticulos[$i]);
            $articulo->stock -= $data->cantidad[$i];
            $articulo->save();

            $venta->save();
        }

        storeControl('registro venta de medicamentos');


        return back()->with(['info' => 'Venta Registrada con Exito', 'color' => 'success', 'factura' => $factura->id, 'clienteid' => $cliente_id]);
    }

    // paga una venta al credito
    public function pagarCredito($id)
    {
        $venta = Venta::find($id);
        $venta->credito = false;
        $venta->save();
        return back()->with(['info' => 'Articulo Cancelado', 'color' => 'success']);
    }

    // imprime la factura de una venta realizada
    public function ventaPrint($idFactura)
    {
        $deuda = DB::table('venta_articulos AS ven')
            ->join('articulos AS art', 'ven.articulo_id', '=', 'art.id')
            ->join('pacientes as pac', 'ven.paciente_id', '=', 'pac.id')
            ->join('facturas AS fac', 'ven.factura_id', '=', 'fac.id')
            ->select(
                'ven.id',
                'ven.factura_id',
                'ven.cantidad',
                'ven.total',
                'ven.credito',
                'ven.mayorista',
                'ven.descuento',
                'ven.cliente',
                'art.nombre as nomArt',
                'art.cod_barras',
                'art.descripcion',
                'art.p_venta',
                'fac.created_at as fechaVenta',
                'fac.descuento as facDescuento',
                'fac.total as facTotal',
                'pac.nombre'
            )
            ->where('ven.credito', 0)
            ->where('ven.factura_id', $idFactura)
            ->get();

        $facturaVenta = Factura::find($idFactura);

        $totalDeuda = 0;
        $nombre = '';
        $fecha = date('Y');
        $nit = 0;
        $descuento_articulo = 0;
        $sin_desc = 0;
        $mayorista = false;
        $facTotal = 0;
        $aux3 = 0;
        foreach ($deuda as $deu) {
            $totalDeuda =  $deu->total + $totalDeuda;
            $nombre = $deu->cliente;
            $fecha = $deu->fechaVenta;
            $descuento_articulo = $descuento_articulo + $deu->descuento;
            $sin_desc = ($sin_desc + $deu->p_venta) * $deu->cantidad;
            $facTotal = $deu->facTotal;
       

            if ($deu->mayorista == 1) {
                $mayorista = true;

                $aux3 = $aux3 + $deu->total;
            }
        }

        return view('reports.ventas.venta', ['deuda' => $deuda, 'totalDeuda' => $totalDeuda, 'cliente' => $nombre, 'factura' => $facturaVenta, 'fecha' => $fecha, 'nit' => $nit, 'descuetoArticulos' => $descuento_articulo, 'sin_desc' => $sin_desc, 'mayorista' => $mayorista, 'facTotal' => $facTotal, 'totalSinDecMayo' => $aux3]);
    }


    // devuelve el hoitorial de las ventas realizadas
    public function historial()
    {
        $contado = DB::table('venta_articulos AS ven')
            ->join('articulos AS art', 'ven.articulo_id', '=', 'art.id')
            ->select(
                'ven.id',
                'ven.factura_id',
                'ven.articulo_id',
                'ven.cantidad',

                'ven.total',
                'ven.credito',
                'ven.mayorista',
                'ven.created_at as fechaVenta',
                'ven.cliente',
                'art.nombre as nomArt',
                'art.cod_barras',
                'art.descripcion'
            )
            ->groupBy('ven.factura_id')
            ->orderBy('fechaVenta', 'desc')
            ->where('ven.deleted_at', null)
            ->get();

        // dd($contado);

        $credito = DB::table('venta_articulos AS ven')

            ->join('articulos AS art', 'ven.articulo_id', '=', 'art.id')
            ->select(
                'ven.id',
                'ven.factura_id',
                'ven.articulo_id',
                'ven.cantidad',
                'ven.total',
                'ven.credito',
                'ven.created_at as fechaVenta',

                'art.nombre as nomArt',
                'art.cod_barras',
                'art.descripcion'
            )
            ->where('ven.credito', 1)
            ->groupBy('ven.factura_id')
            ->where('ven.deleted_at', null)

            ->get();

        //////---------------------------------------

        return view('admin.ventas.historial', ['contado' => $contado, 'credito' => $credito]);
    }

    // elimina una venta y actualiza el stock en los articulos
    public function destroy($id, $idArt)
    {
        $venta = Venta::where('factura_id', $id)->get();
        foreach ($venta as $venta) {

            $articulo = Articulo::find($venta->articulo_id);
            $articulo->stock = $articulo->stock + $venta->cantidad;
            $articulo->save();
            $venta->forceDelete();
        }

        storeControl('elimino una venta de medicamentos');

        return back()->with(['info' => 'Venta Anulda Con Exito', 'color' => 'danger']);
    }

    // devuelve la vista para los reportes
    public function reportes()
    {
        return view('admin.ventas.reportes');
    }

    // devuelve la vista para reporte de todas las ventas 
    public function reportesVentasAll(Request $data)
    {
        $ventas = DB::table('venta_articulos AS ven')
            ->join('articulos AS art', 'ven.articulo_id', '=', 'art.id')
            ->join('facturas AS fac', 'ven.factura_id', '=', 'fac.id')
            ->select(
                'ven.id',
                'ven.factura_id',
                'ven.articulo_id',
                'ven.cantidad',
                'ven.total',
                'ven.descuento',
                'ven.credito',
                'ven.created_at as fechaVenta',
                'ven.cliente',
                'art.nombre as nomArt',
                'art.cod_barras',
                'art.descripcion',
                'art.p_venta',
                'art.p_costo',
                'fac.total as facTotal',
                'fac.descuento  as facDec',
                'fac.id  as facid',
                'fac.descripcion as facDes'
            )
            ->whereMonth('ven.created_at', $data->mes)
            ->whereYear('ven.created_at', $data->ano)
            ->where('ven.mayorista', false)
            ->get();

        // dd($ventas);


        // return $ventas;

        $ventas_mayoristas = DB::table('venta_articulos AS ven')
            ->join('facturas AS fac', 'ven.factura_id', '=', 'fac.id')
            ->select(
                'ven.created_at as fechaVenta',
                'fac.total as facTotal',
                'fac.descuento  as facDec',
                'fac.id  as facid',
                'fac.descripcion as facDes'
            )
            ->whereMonth('ven.created_at', $data->mes)
            ->whereYear('ven.created_at', $data->ano)
            ->where('ven.mayorista', true)
            ->groupBy('fac.id')
            ->get();

        $ventas_mayoristas2 = DB::table('venta_articulos AS ven')
            ->join('articulos AS art', 'ven.articulo_id', '=', 'art.id')
            ->join('facturas AS fac', 'ven.factura_id', '=', 'fac.id')
            ->select(
                'ven.id',
                'ven.factura_id',
                'ven.articulo_id',
                'ven.cantidad',
                'ven.total',
                'ven.descuento',
                'ven.credito',
                'ven.created_at as fechaVenta',
                'ven.cliente',
                'art.nombre as nomArt',
                'art.cod_barras',
                'art.descripcion',
                'art.p_venta',
                'art.p_costo',
                'fac.total as facTotal',
                'fac.descuento  as facDec',
                'fac.id  as facid',
                'fac.descripcion as facDes'
            )
            ->whereMonth('ven.created_at', $data->mes)
            ->whereYear('ven.created_at', $data->ano)
            ->where('ven.mayorista', true)
            ->get();
        $ventasEsperadasMayo = 0;

        foreach ($ventas_mayoristas2 as $ventaMayo) {
            $ventasEsperadasMayo = $ventasEsperadasMayo + $ventaMayo->total;
        }


        $total = 0;
        foreach ($ventas as $ven) {
            $total = $ven->total + $total;
            // echo $total, '.', $ven->total, '<br>';
        }

        // die();
        return view('reports.ventas.ventas', ['ventas' => $ventas, 'total' => $total, 'mes' => $data->mes, 'ano' => $data->ano, 'ventas_mayo' => $ventas_mayoristas, 'total_mayo' => $ventasEsperadasMayo]);
    }

    // devuelve la vista para imprimir reportes de ventas al contado
    public function reportesVentasContado(Request $data)
    {
        $ventas = $this->ventasContado($data->mes, $data->ano);
        $total = 0;
        foreach ($ventas as $ven) {
            $total = $ven->total + $total;
        }
        return view('reports.ventas.ventas', ['ventas' => $ventas, 'total' => $total, 'tipo' => 'al contado', 'mes' => $data->mes, 'ano' => $data->ano]);
    }

    // devuelve la vista par imprimir reportes de ventas al credito
    public function reportesVentasCredito(Request $data)
    {
        $ventas = $this->ventasCrediro($data->mes, $data->ano);
        $total = 0;
        foreach ($ventas as $ven) {
            $total = $ven->total + $total;
        }


        return view('reports.ventas.ventas', ['ventas' => $ventas, 'total' => $total, 'tipo' => 'al credito', 'mes' => $data->mes, 'ano' => $data->ano]);
    }


    // ---------------------------------------------------
    // ventas all
    public function allventas($mes, $ano)
    {
        $ventas = DB::table('venta_articulos AS ven')
            ->join('articulos AS art', 'ven.articulo_id', '=', 'art.id')
            ->join('facturas AS fac', 'ven.factura_id', '=', 'fac.id')
            ->select(
                'ven.id',
                'ven.factura_id',
                'ven.articulo_id',
                'ven.cantidad',
                'ven.cliente',
                'ven.total',
                'ven.descuento',
                'ven.credito',
                'ven.created_at as fechaVenta',
                'art.nombre as nomArt',
                'art.cod_barras',
                'art.descripcion',
                'art.p_venta',
                'fac.total as facTotal',
                'fac.descuento  as facDec',
                'fac.id  as facid',
                'fac.descripcion as facDes'
            )
            ->whereMonth('ven.created_at', $mes)
            ->whereYear('ven.created_at', $ano)
            // ->where('ven.mayorista' ,'!=', true)
            ->get();

        return $ventas;
    }

    // ventas al contado
    public function ventasContado($mes, $ano)
    {
        $contado = DB::table('venta_articulos AS ven')
            ->join('articulos AS art', 'ven.articulo_id', '=', 'art.id')
            ->select(
                'ven.id',
                'ven.factura_id',
                'ven.articulo_id',
                'ven.cantidad',
                'ven.total',
                'ven.credito',
                'ven.created_at as fechaVenta',
                'ven.cliente',
                'art.nombre as nomArt',
                'art.cod_barras',
                'art.descripcion',
                'art.p_venta',
                'art.p_costo',
                'ven.descuento'
            )
            ->where('ven.credito', 0)
            ->whereMonth('ven.created_at', $mes)
            ->whereYear('ven.created_at', $ano)
            ->get();
        return $contado;
    }

    // ventas al credito
    public function ventasCrediro($mes, $ano)
    {
        $credito = DB::table('venta_articulos AS ven')

            ->join('articulos AS art', 'ven.articulo_id', '=', 'art.id')
            ->select(
                'ven.id',
                'ven.factura_id',
                'ven.articulo_id',
                'ven.cantidad',
                'ven.total',
                'ven.credito',
                'ven.created_at as fechaVenta',
                'ven.cliente',
                'art.nombre as nomArt',
                'art.cod_barras',
                'art.descripcion',
                'art.p_venta',
                'art.p_costo',
                'ven.descuento'
            )
            ->where('ven.credito', 1)
            ->whereMonth('ven.created_at', $mes)
            ->whereYear('ven.created_at', $ano)
            ->get();
        return $credito;
    }


    public function ventasDia()
    {
        $ventas = DB::table('venta_articulos AS ven')
            ->join('articulos AS art', 'ven.articulo_id', '=', 'art.id')
            ->join('facturas AS fac', 'ven.factura_id', '=', 'fac.id')
            ->select(
                'ven.id',
                'ven.factura_id',
                'ven.articulo_id',
                'ven.cantidad',
                'ven.total',
                'ven.descuento',
                'ven.credito',
                'ven.created_at as fechaVenta',
                'art.nombre as nomArt',
                'art.cod_barras',
                'art.descripcion',
                'art.p_venta',
                'art.p_costo',
                'fac.total as facTotal',
                'fac.descuento  as facDec',
                'fac.id  as facid',
                'fac.descripcion as facDes'
            )
            ->whereDate('ven.created_at', date('Y-m-d'))
            ->where('ven.deleted_at', null)
            // ->where('ven.mayorista' ,'!=', true)
            ->get();

        return view('reports.ventas.dia', ['ventas' => $ventas]);
    }

    // ultimos movimientos
    public function movimientos()
    {
        $ventas = DB::table('venta_articulos AS ven')
            ->join('articulos AS art', 'ven.articulo_id', '=', 'art.id')
            ->join('facturas AS fac', 'ven.factura_id', '=', 'fac.id')
            ->select(
                'ven.id',
                'ven.factura_id',
                'ven.articulo_id',
                'ven.cantidad',
                'ven.total',
                'ven.descuento',
                'ven.credito',
                'ven.created_at as fechaVenta',
                'art.nombre as nomArt',
                'art.cod_barras',
                'art.descripcion',
                'art.p_venta',
                'art.p_costo',
                'fac.total as facTotal',
                'fac.descuento  as facDec',
                'fac.id  as facid',
                'fac.descripcion as facDes'
            )
            ->whereDate('ven.created_at', date('Y-m-d'))
            // ->where('ven.mayorista' ,'!=', true)
            ->take(15)
            ->get();


        return view('reports.ventas.dia', ['ventas' => $ventas]);
    }


    // retorna la vista para las estadisticas
    public function estadistica()
    {
        $estadisticasano = $this->estadis();
        $masVendidos = $this->masVendidos();


        // for ($i = 0; $i < sizeof($this->movimientoMes()); $i++) {
        //     foreach ($this->movimientoMes()[$i] as $movi) {

        //         echo $movi->created_at . ':';
        //         echo $movi->cuadre .'<br>';
        //     }
        // }

        // dd();
        return view('reports.ventas.estadistica', ['datos' => $estadisticasano, 'masVendidos' => $masVendidos]);
    }

    // retorna los datos de entradas de efectico
    // para construir las graficas estadisticass
    public function estadis()
    {

        $ventasEnero = $this->ventasMes(1);
        $ventasFebrero = $this->ventasMes(2);
        $ventasMarzo = $this->ventasMes(3);
        $ventasAbril = $this->ventasMes(4);
        $ventasMayo = $this->ventasMes(5);
        $ventasJunio = $this->ventasMes(6);
        $ventasJulio = $this->ventasMes(7);
        $ventasAgosto = $this->ventasMes(8);
        $ventasSptiembre = $this->ventasMes(9);
        $ventasOctubre = $this->ventasMes(10);
        $ventasNoviembre = $this->ventasMes(11);
        $ventasDiciembre = $this->ventasMes(12);
        $totales = array();
        $total1 = 0;
        $total2 = 0;
        $total3 = 0;
        $total4 = 0;
        $total5 = 0;
        $total6 = 0;
        $total7 = 0;
        $total8 = 0;
        $total9 = 0;
        $total10 = 0;
        $total11 = 0;
        $total12 = 0;

        foreach ($ventasEnero as $venta) {
            $total1 = $total1 +  $venta->cuadre;
        }
        foreach ($ventasFebrero as $venta) {
            $total2 = $total2 +  $venta->cuadre;
        }
        foreach ($ventasMarzo as $venta) {
            $total3 = $total3 +  $venta->cuadre;
        }

        foreach ($ventasAbril as $venta) {
            $total4 = $total4 +  $venta->cuadre;
        }
        foreach ($ventasMayo as $venta) {
            $total5 = $total5 +  $venta->cuadre;
        }
        foreach ($ventasJunio as $venta) {
            $total6 = $total6 +  $venta->cuadre;
        }
        foreach ($ventasJulio as $venta) {
            $total7 = $total7 +  $venta->cuadre;
        }
        foreach ($ventasAgosto as $venta) {
            $total8 = $total8 +  $venta->cuadre;
        }
        foreach ($ventasSptiembre as $venta) {
            $total9 = $total9 +  $venta->cuadre;
        }
        foreach ($ventasOctubre as $venta) {
            $total10 = $total10 +  $venta->cuadre;
        }
        foreach ($ventasNoviembre as $venta) {
            $total11 = $total11 +  $venta->cuadre;
        }
        foreach ($ventasDiciembre as $venta) {
            $total12 = $total12 +  $venta->cuadre;
        }



        array_push($totales, $total1, $total2, $total3, $total4, $total5, $total6, $total7, $total8, $total9, $total10, $total11, $total12);


        return $totales;
    }

    // retorna  los cuadres de caja por mes
    public function ventasMes($mes)
    {
        $data =
            DB::table('cuadres')
            ->whereMonth('created_at', $mes)
            ->whereYear('created_at', date('Y'))
            ->get();
        return $data;
    }


    // retorna un listadode articulos mas vendidos
    public function masVendidos()
    {
        $data =  DB::table('venta_articulos')
            ->join('articulos as art', 'venta_articulos.articulo_id', '=', 'art.id')
            ->select(DB::raw('COUNT(venta_articulos.articulo_id) as idArticulo'), 'venta_articulos.factura_id', 'art.nombre', 'art.descripcion')
            ->groupBy('venta_articulos.articulo_id')
            ->orderBy(DB::raw('venta_articulos.articulo_id'), 'desc')
            ->limit(25)
            ->get();
        $data2 = array();
        foreach ($data as $d) {
            array_push($data2, $d);
        }
        return $data2;
    }



    public function movimientoMes()
    {
        $dias = array();
        for ($i = 0; $i < 32; $i++) {
            $data =
                DB::table('cuadre')
                ->whereDay('created_at', $i)
                ->whereMonth('created_at', date('m'))
                ->whereYear('created_at', date('Y'))
                ->get();
            array_push($dias, $data);
        }
        return $dias;
    }
}
